@@ -234,34 +234,34 @@ class S3ToStepfunctions(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3BucketInterface")
     def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
         return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="stateMachine")
     def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
         return typing.cast(aws_cdk.aws_stepfunctions.StateMachine, jsii.get(self, "stateMachine"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="stateMachineLogGroup")
     def state_machine_log_group(self) -> aws_cdk.aws_logs.ILogGroup:
         return typing.cast(aws_cdk.aws_logs.ILogGroup, jsii.get(self, "stateMachineLogGroup"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3Bucket"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3LoggingBucket"))
@@ -310,15 +310,15 @@ class S3ToStepfunctionsProps:
         :summary: The properties for the S3ToStepfunctions Construct
         '''
         if isinstance(state_machine_props, dict):
-            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
+            state_machine_props = StateMachineProps(**state_machine_props)
         if isinstance(bucket_props, dict):
-            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
+            bucket_props = BucketProps(**bucket_props)
         if isinstance(event_rule_props, dict):
-            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
+            event_rule_props = RuleProps(**event_rule_props)
         if isinstance(logging_bucket_props, dict):
-            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
+            logging_bucket_props = BucketProps(**logging_bucket_props)
         if isinstance(log_group_props, dict):
-            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+            log_group_props = LogGroupProps(**log_group_props)
         if __debug__:
             type_hints = typing.get_type_hints(S3ToStepfunctionsProps.__init__)
             check_type(argname="argument state_machine_props", value=state_machine_props, expected_type=type_hints["state_machine_props"])
